networking

package
v0.0.0-...-7266528 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetPageStatus

func GetPageStatus(rancherConfig *rancher.Config, setting string) error

GetPageStatus is a function that will attempt to load the Rancher UI's ui.min.js file from both the /v3 and /v1 API endpoints.

func VerifyClusterConnectivity

func VerifyClusterConnectivity(client *rancher.Client, clusterID string, serviceID string, path string, content string) error

VerifyClusterConnectivity verifies that the ClusterIP service is accessible via SSH from a worker node

func VerifyHostPortConnectivity

func VerifyHostPortConnectivity(client *rancher.Client, clusterID string, hostPort int, workloadName string) error

VerifyHostPortConnectivity verifies that the host port is accessible on worker nodes by SSHing directly into each node

func VerifyNetworkPolicy

func VerifyNetworkPolicy(client *rancher.Client, clusterID string, namespaceName string) error

VerifyNetworkPolicy verifies that the network policy is working by pinging the pods from the node

func VerifyNodePortConnectivity

func VerifyNodePortConnectivity(client *rancher.Client, clusterID string, nodePort int, workloadName string) error

VerifyNodePortConnectivity verifies that the node port is accessible by curling the worker node external IP

Types

This section is empty.

Jump to