services

package
v0.0.0-...-abb0ee4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 25 Imported by: 1

Documentation

Index

Constants

const (
	ServiceSteveType = "service"
)

Variables

This section is empty.

Functions

func CreateService

func CreateService(steveclient *steveV1.Client, service corev1.Service) (*steveV1.SteveAPIObject, error)

CreateService is a helper function to create a service in the downstream cluster

func NewServiceTemplate

func NewServiceTemplate(serviceName, namespaceName string, serviceType corev1.ServiceType, ports []corev1.ServicePort, selector map[string]string) corev1.Service

NewServiceTemplate is a constructor that creates the service template for services

func NewServiceTemplateWithAnnotations

func NewServiceTemplateWithAnnotations(serviceName, namespaceName string, serviceType corev1.ServiceType, ports []corev1.ServicePort, selector, annotations map[string]string) corev1.Service

NewServiceTemplateWithAnnotations is a constructor that creates the service with annotations template for services

func VerifyAWSLoadBalancer

func VerifyAWSLoadBalancer(t *testing.T, client *rancher.Client, serviceLB *v1.SteveAPIObject, clusterName string)

VerifyAWSLoadBalancer validates that an AWS loadbalancer service is created and working properly

func VerifyClusterIP

func VerifyClusterIP(client *rancher.Client, clusterName string, clusterID string, serviceID string, path string, content string) error

VerifyClusterIP is a helper function that verifies the cluster is able to connect to the cluster ip service by ssh shell

func VerifyHarvesterLoadBalancer

func VerifyHarvesterLoadBalancer(t *testing.T, client *rancher.Client, serviceLB *v1.SteveAPIObject, clusterName string)

VerifyHarvesterLoadBalancer validates that a Harvester loadbalancer service is created and working properly

func VerifyService

func VerifyService(steveclient *steveV1.Client, serviceResp *steveV1.SteveAPIObject) error

VerifyService waits for a service to be ready in the downstream cluster

Types

This section is empty.

Jump to