Documentation
¶
Index ¶
- func GetPageStatus(rancherConfig *rancher.Config, setting string) error
- func VerifyClusterConnectivity(client *rancher.Client, clusterID string, serviceID string, path string, ...) error
- func VerifyHostPortConnectivity(client *rancher.Client, clusterID string, hostPort int, workloadName string) error
- func VerifyNetworkPolicy(client *rancher.Client, clusterID string, namespaceName string) error
- func VerifyNodePortConnectivity(client *rancher.Client, clusterID string, nodePort int, workloadName string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetPageStatus ¶
GetPageStatus is a function that will attempt to load the Rancher UI's ui.min.js file from both the /v3 and /v1 API endpoints.
func VerifyClusterConnectivity ¶
func VerifyClusterConnectivity(client *rancher.Client, clusterID string, serviceID string, path string, content string) error
VerifyClusterConnectivity verifies that the ClusterIP service is accessible via SSH from a worker node
func VerifyHostPortConnectivity ¶
func VerifyHostPortConnectivity(client *rancher.Client, clusterID string, hostPort int, workloadName string) error
VerifyHostPortConnectivity verifies that the host port is accessible on worker nodes by SSHing directly into each node
func VerifyNetworkPolicy ¶
VerifyNetworkPolicy verifies that the network policy is working by pinging the pods from the node
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.